@@ -34,6 +34,8 @@ from flask.ext.admin.babel import gettext, lazy_gettext
 
 from werkzeug import secure_filename
 
+from flask_login import login_required
+
 class ShelfModelView(sqla.ModelView):
     list_template = "shelf-admin/model/list.html"
     create_template = "shelf-admin/model/create.html"
@@ -177,7 +179,13 @@ class ShelfModelView(sqla.ModelView):
 
             flash(gettext('Failed to delete models. %(error)s', error=str(ex)), 'error')
 
+    @expose('/')
+    @login_required
+    def index_view(self):
+        return super(ShelfModelView, self).index_view()
+
     @expose('/new/', methods=('GET', 'POST'))
+    @login_required
     def create_view(self):
         """
             Create model view
@@ -205,7 +213,9 @@ class ShelfModelView(sqla.ModelView):
                            form_rules=self._form_create_rules,
                            return_url=return_url)
 
+    
     @expose('/edit/', methods=('GET', 'POST'))
+    @login_required
     def edit_view(self):
         """
             Edit model view
@@ -290,7 +300,7 @@ class ShelfPageView(ShelfModelView):
             raise ValueError
 
         if obj.__class__ in self.pages_form:
-            return self.pages_form[obj.__class__]()
+            return self.pages_form[obj.__class__](get_form_data(), obj=obj)
 
         converter = self.model_form_converter(self.session, self)
         cls = contribform.get_form(obj.__class__, converter,
@@ -323,6 +333,7 @@ class ShelfPageView(ShelfModelView):
         return cls(get_form_data(), obj=obj)
 
     def update_model(self, form, model):
+        print form.faqs
         return super(ShelfPageView, self).update_model(form, model)
 
 
